<?php
namespace Ak\Task\Handler;

use Ak\Form\FormElementManager;
use Ak\Orm\Form\EntityForm;
use Ak\Task\Form\TaskForm;
use Ak\Task\TaskInterface;
use Doctrine\ORM\EntityManagerInterface;
use Psr\Container\ContainerInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Mezzio\Helper\UrlHelper;
use Laminas\View\Renderer\RendererInterface;

/**
 * Class AbstractHandler
 *
 * @package Ak\Task\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/task
 */
abstract class AbstractHandler implements RequestHandlerInterface
{
    /** @var EntityManagerInterface */
    protected $em;
    /** @var RendererInterface */
    private $renderer;
    /** @var FormElementManager */
    private $forms;
    /** @var UrlHelper */
    protected $urlHelper;
    /** @var array */
    protected $config;
    /** @var ContainerInterface */
    protected $container;

    /**
     * Konstruktor.
     *
     * @param EntityManagerInterface $em
     * @param RendererInterface $renderer
     * @param FormElementManager $forms
     * @param UrlHelper $urlHelper
     */
    public function __construct(
        EntityManagerInterface $em,
        RendererInterface $renderer,
        FormElementManager $forms,
        UrlHelper $urlHelper,
        array $config,
        ContainerInterface $container
    ) {
        $this->em = $em;
        $this->renderer = $renderer;
        $this->forms = $forms;
        $this->urlHelper = $urlHelper;
        $this->config = $config['task_manager'] ?? [];
        $this->container = $container;
    }

    /**
     * @param string $template
     * @param array $vars
     * @return string
     */
    protected function render(string $template, array $vars = []): string
    {
        $tasks = [];

        foreach ($this->config['tasks'] as $slug => $task) {
            $tasks[$slug] = $task['label'];
        }

        return $this->renderer->render('task-manager/layout', [
            'tasks' => $tasks,
            'content' => $this->renderer->render($template, $vars),
        ]);
    }

    protected function getForm(TaskInterface $task)
    {
        /** @var TaskForm $form */
        $form = $this->forms->get(get_class($task));
        $form->bind($task);

        return $form;
    }
}
