<?php
namespace Ak\Task\Handler;

use Ak\Task\Task;
use Ak\Task\TaskInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Laminas\Diactoros\Response\HtmlResponse;
use Laminas\Diactoros\Response\RedirectResponse;

/**
 * Class Delete
 *
 * @package Ak\Task\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/b2b-app
 */
final class Delete extends AbstractHandler
{
    /**
     * Handles a request and produces a response.
     *
     * May call other collaborating code to generate the response.
     *
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        $id = $request->getAttribute('id');
        /** @var TaskInterface $task */
        $task = $this->em->find(Task::class, $id);

        if ($request->getMethod() === 'POST') {
            $data = $request->getParsedBody();

            if ('yes' === ($data['delete'] ?? 'no')) {
                $this->em->remove($task);
            }

            return new RedirectResponse(
                $this->urlHelper->generate('task-manager')
            );
        }

        return new HtmlResponse(
            $this->render('task-manager/delete', [
                'task' => $task,
            ])
        );
    }
}
