<?php
namespace Ak\Task\Handler;

use Ak\Container\ContainerAwareInterface;
use Ak\Task\Task;
use Ak\Task\TaskInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Laminas\Diactoros\Response\HtmlResponse;
use Laminas\Diactoros\Response\RedirectResponse;

/**
 * Class Run
 *
 * @package Ak\Task\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/task
 */
final class Run extends AbstractHandler
{
    /**
     * Handles a request and produces a response.
     *
     * May call other collaborating code to generate the response.
     *
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        $id = $request->getAttribute('id');
        /** @var TaskInterface $task */
        $task = $this->em->find(Task::class, $id);

        if ($task instanceof ContainerAwareInterface) {
            $task->setContainer($this->container);
        }

        $task->run();

        return new RedirectResponse(
            $this->urlHelper->generate('task-manager.details', ['id' => $task->getId()])
        );
    }
}
